@@ -1,5 +1,5 @@
 package CHI::Driver;
-$CHI::Driver::VERSION = '0.59';
+$CHI::Driver::VERSION = '0.61';
 use Carp;
 use CHI::CacheObject;
 use CHI::Constants qw(CHI_Max_Time);
@@ -849,14 +849,14 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.59
+version 0.61
 
 =head1 DESCRIPTION
 
 This is the base class that all CHI drivers inherit from. It provides the
 methods that one calls on $cache handles, such as get() and set().
 
-See L<CHI/METHODS> for documentation on $cache methods, and
+See L<CHI/INSTANCE METHODS> for documentation on $cache methods, and
 L<CHI::Driver::Development|CHI::Driver::Development> for documentation on
 creating new subclasses of CHI::Driver.
 
@@ -870,7 +870,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jonathan Swartz.
+This software is copyright (c) 2021 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
